/******************************************************************************
 *
 * $Id: declinfo.h,v 1.8 2001/03/19 19:27:40 root Exp $
 *
 * Copyright (C) 1997-2013 by Dimitri van Heesch.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation under the terms of the GNU General Public License is hereby 
 * granted. No representations are made about the suitability of this software 
 * for any purpose. It is provided "as is" without express or implied warranty.
 * See the GNU General Public License for more details.
 *
 * Documents produced by Doxygen are derivative works derived from the
 * input used in their production; they are not affected by this license.
 *
 */

#ifndef DECLINFO_H
#define DECLINFO_H

#include <stdio.h>
#include <qcstring.h>

extern void parseFuncDecl(const QCString &decl,
                          bool objC,
                          QCString &clName,
                          QCString &type,
                          QCString &name,
                          QCString &args,
                          QCString &funcTempList,
                          QCString &exceptions
                         );
#endif
